![Publish cryptlex.lexactivator package](https://github.com/cryptlex/lexactivator-python/workflows/Publish%20cryptlex.lexactivator%20package/badge.svg)

# cryptlex.lexactivator

Cryptlex lets you license your software apps effortlessly. You can easily generate license keys using the REST API or Dashboard and validate the license keys in your software apps using LexActivator (Cryptlex client library).

Additionally, you can offer trials, subscriptions, floating licenses and much more.

**cryptlex.lexactivator** is a Python wrapper for LexActivator licensing library.

## Installation

    pip install cryptlex.lexactivator

Then you can include it in your code:

	from cryptlex.lexactivator import LexActivator, LexStatusCodes, PermissionFlags, LexActivatorException


## Usage
Refer to following for documentation:

https://docs.cryptlex.com/node-locked-licenses/using-lexactivator/using-lexactivator-with-python
